@@ -302,10 +302,14 @@ setMethod(
             yax <- eval(object@data$yax, envir = sys.frame(object@data$frame))
         }
         
-        graphsnames <- c("object", "densX", "densY", "link") 
         ## sorting parameters
+        graphsnames <- c("object", "densX", "densY", "link") 
         sortparameters <- sortparamADEgS(..., graphsnames = graphsnames)
+        params <- vector("list", 4)
+        names(params) <- graphsnames
+        sortparameters <- modifyList(params, sortparameters, keep.null = TRUE)
         update(object, sortparameters[[1]], plot = FALSE)
+        
         ## setting positions
         positions <- layout2position(matrix(c(2, 4, 1, 3), 2, 2, byrow = TRUE), c(3, 1) / 2, c(3, 1) / 2, FALSE)
 
@@ -329,7 +333,9 @@ setMethod(
         
         ## limits and graduation
         dfxaxcall <- call("[", dfxycall, 1:NROW(eval(dfxycall)), substitute(xax))
+        dfxaxcallplus <- call("~", dfxaxcall, 1)
         dfyaxcall <- call("[", dfxycall, 1:NROW(eval(dfxycall)), substitute(yax))
+        dfyaxcallplus <- call("~", dfyaxcall, 1)
         limcalX <- hist(dfxy[, xax], breaksX, plot = FALSE)
         limcalXcall <- call("hist", substitute(dfxaxcall), breaksX, plot = FALSE)
         limcalY <- hist(dfxy[, yax], breaksY, plot = FALSE)
@@ -342,33 +348,41 @@ setMethod(
 
         if(!missing(bandwidth)) {
             densiX <- bkde(dfxy[, xax], kernel = kernel, bandwidth = bandwidth, gridsize = gridsize)
+            densiXcall <- call("bkde", substitute(dfxaxcall), kernel = kernel, bandwidth = bandwidth, gridsize = gridsize)
             densiY <- bkde(dfxy[, yax], kernel = kernel, bandwidth = bandwidth, gridsize = gridsize)
+            densiYcall <- call("bkde", substitute(dfyaxcall), kernel = kernel, bandwidth = bandwidth, gridsize = gridsize)
         } else {
             densiX <- bkde(dfxy[, xax], kernel = kernel, gridsize = gridsize)
+            densiXcall <- call("bkde", substitute(dfxaxcall), kernel = kernel, gridsize = gridsize)
             densiY <- bkde(dfxy[, yax], kernel = kernel, gridsize = gridsize)
+            densiYcall <- call("bkde", substitute(dfyaxcall), kernel = kernel, gridsize = gridsize)
         }
         
         ## trellis creation 
-        g2 <- xyplot(dfxy[, xax] ~ 1, xlim = xlimX, ylim = ylimX, horizontal = TRUE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, histValues = limcalX, drawLines = drawLines, 
-                     panel = function(histValues, horizontal, drawLines) adeg.panel.hist(histValues = histValues, horizontal = horizontal, 
-                                                                                         drawLines = drawLines, densi = densiX, params = sortparameters[[2]]))
-        g2$call <- call("xyplot", dfxaxcall, xlim = substitute(xlimX), ylim = substitute(ylimX), horizontal = TRUE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, 
-                        histValues = limcalXcall, drawLines = substitute(drawLines),
-                        panel = function(histValues, horizontal, drawLines) adeg.panel.hist(histValues = histValues, horizontal = horizontal, 
-                                                                                            drawLines = drawLines, densi = densiX, params = sortparameters[[2]]))
-
-        g3 <- xyplot(dfxy[, yax] ~ 1, xlim = xlimY, ylim = ylimY, horizontal = FALSE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, histValues = limcalY, drawLines = drawLines, 
-                     panel = function(histValues, horizontal, drawLines) adeg.panel.hist(histValues = histValues, densi = densiY, horizontal = horizontal, 
-                                                                                         drawLines = drawLines, params = sortparameters[[3]]))
-        g3$call <- call("xyplot", dfyaxcall ~ 1, xlim = substitute(xlimY), ylim = substitute(ylimY), horizontal = FALSE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, 
-                        histValues = limcalYcall, drawLines = substitute(drawLines), 
-                        panel = function(histValues, horizontal, drawLines) adeg.panel.hist(histValues = histValues, densi = densiY, horizontal = horizontal, 
-                                                                                            drawLines = drawLines, params = sortparameters[[3]]))
+        g2 <- xyplot(dfxy[, xax] ~ 1, xlim = xlimX, ylim = ylimX, horizontal = TRUE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, histValues = limcalX, 
+                     drawLines = drawLines, densi = densiX, params = sortparameters[[2]], 
+                     panel = function(histValues, horizontal, drawLines, densi, params) adeg.panel.hist(histValues = histValues, horizontal = horizontal, 
+                                                                                         drawLines = drawLines, densi = densi, params = params))
+        g2$call <- call("xyplot", dfxaxcallplus, xlim = substitute(xlimX), ylim = substitute(ylimX), horizontal = TRUE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, 
+                        histValues = limcalXcall, drawLines = substitute(drawLines), densi = substitute(densiXcall), params = sortparameters[[2]], 
+                        panel = function(histValues, horizontal, drawLines, densi, params) adeg.panel.hist(histValues = histValues, horizontal = horizontal, 
+                                                                                            drawLines = drawLines, densi = densi, params = params))
         
-        g4 <- xyplot(1 ~ 1, xlim = xlimY, ylim = ylimX, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, drawLines = drawLines, 
-                     panel = function(drawLines) adeg.panel.join(drawLines = drawLines, params = sortparameters[[4]]))
-        g4$call <- call("xyplot", 1 ~ 1, xlim = substitute(xlimY), ylim = substitute(ylimX), scales = list(draw = FALSE), xlab = NULL, ylab = NULL, 
-                        drawLines = substitute(drawLines), panel = function(drawLines) adeg.panel.join(drawLines = drawLines, params = sortparameters[[4]]))
+        
+        g3 <- xyplot(dfxy[, yax] ~ 1, xlim = xlimY, ylim = ylimY, horizontal = FALSE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, histValues = limcalY, 
+                     drawLines = drawLines, densi = densiY, params = sortparameters[[3]], 
+                     panel = function(histValues, horizontal, drawLines, densi, params) adeg.panel.hist(histValues = histValues, horizontal = horizontal, 
+                                                                                         drawLines = drawLines, densi = densi, params = params))
+        g3$call <- call("xyplot", dfyaxcallplus, xlim = substitute(xlimY), ylim = substitute(ylimY), horizontal = FALSE, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, 
+                        histValues = limcalYcall, drawLines = substitute(drawLines), densi = substitute(densiYcall), params = sortparameters[[3]], 
+                        panel = function(histValues, horizontal, drawLines, densi, params) adeg.panel.hist(histValues = histValues, horizontal = horizontal, 
+                                                                                            drawLines = drawLines, densi = densi, params = params))
+        
+        
+        g4 <- xyplot(1 ~ 1, xlim = xlimY, ylim = ylimX, scales = list(draw = FALSE), xlab = NULL, ylab = NULL, drawLines = drawLines, params = sortparameters[[4]], 
+                     panel = function(drawLines, params) adeg.panel.join(drawLines = drawLines, params = params))
+        g4$call <- call("xyplot", 1 ~ 1, xlim = substitute(xlimY), ylim = substitute(ylimX), scales = list(draw = FALSE), xlab = NULL, ylab = NULL, drawLines = substitute(drawLines), 
+                        params = sortparameters[[4]], panel = function(drawLines, params) adeg.panel.join(drawLines = drawLines, params = params))
         
         ## ADEgS creation and display
         obj <- new(Class = "ADEgS", ADEglist = list(object, g2, g3, g4), positions = positions, add = matrix(0, ncol = 4, nrow = 4), Call = match.call())
